@@ -3,6 +3,8 @@
 #' to the service. Most ECMWF services are limited to 20 concurrent requests
 #' (default = 2).
 #' @param total_timeout overall timeout limit for all the requests in seconds.
+#' @param retry polling frequency of submitted request for downloading (default =
+#' \code{30} seconds).
 #' @importFrom R6 R6Class
 #'
 #' @rdname wf_request
@@ -10,9 +12,10 @@
 wf_request_batch <- function(
     request_list,
     workers = 2,
-    user,
+    user = "ecmwfr",
     path = tempdir(),
     time_out = 3600,
+    retry = 5,
     total_timeout = length(request_list)*time_out/workers
 ) {
 
@@ -45,6 +48,11 @@ wf_request_batch <- function(
   while (length(done) < length(request_list) & Sys.time() < timeout_time) {
     for (w in seq_along(slots)) {
 
+      # wait before submitting a call
+      # set to the same value is the
+      # retry rate
+      Sys.sleep(retry)
+
       # If a slot is free and there's a queue,
       # assign to it the next pending request,
       # remove that request from the queue
@@ -53,7 +61,9 @@ wf_request_batch <- function(
           queue[[1]],
           user = user[1],
           time_out = time_out[1],
-          path = path[1], transfer = FALSE
+          retry = retry,
+          path = path[1],
+          transfer = FALSE
           )
         queue <- queue[-1]
         user <- user[-1]
